/*
 * (c) Bernd Müller & Harald Wehr, www.jpainfo.de
 */
package de.jpainfo.model;

import java.math.BigDecimal;
import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

@Entity
public class Buchung {
	
	private static final DateFormat format = new SimpleDateFormat("dd.MM.yyyy");
	
	@Id @GeneratedValue
	private Integer id;
	@Column(precision = 10, scale = 2)
	private BigDecimal betrag;
	@Temporal(TemporalType.DATE)
	private Date datum;
	private String text;
	private Buchungsart buchungsart;
	
	@ManyToOne
	@JoinColumn(name = "konto", nullable = false)
	private Konto konto;
	
	
	public Buchung() {
	}

	
	public Buchung(BigDecimal betrag, String datum, String text, Buchungsart buchungsart) {
		this.betrag = betrag;
		this.text = text;
		this.buchungsart = buchungsart;
		
		try {
			this.datum = format.parse(datum);
		} catch (ParseException e) {
			throw new IllegalArgumentException("Falsches Datumsformat");
		}
	}



	// Getter und Setter
	public Integer getId() {
		return id;
	}

	public BigDecimal getBetrag() {
		return betrag;
	}
	public void setBetrag(BigDecimal betrag) {
		this.betrag = betrag;
	}

	public Date getDatum() {
		return datum;
	}
	public void setDatum(Date datum) {
		this.datum = datum;
	}

	public String getText() {
		return text;
	}
	public void setText(String text) {
		this.text = text;
	}

	public Buchungsart getBuchungsart() {
		return buchungsart;
	}
	public void setBuchungsart(Buchungsart buchungsart) {
		this.buchungsart = buchungsart;
	}


	public Konto getKonto() {
		return konto;
	}
	public void setKonto(Konto konto) {
		this.konto = konto;
	}

}
